@@ -76,7 +76,10 @@ pub async fn dog_commander(cmd: DogCommands, output_fmt: OutputFmt, safe: &mut S
                     println!("Resolved from: {}", resolved_from);
                     println!("= FilesContainer =");
                     println!("XOR-URL: {}", xorurl);
-                    println!("Version: {}", version);
+                    println!(
+                        "Version: {}",
+                        version.map_or("none".to_string(), |v| v.to_string())
+                    );
                     println!("Type tag: {}", type_tag);
                     println!("XOR name: 0x{}", xorname_to_hex(xorname));
                     println!("Native data type: {}", data_type);
